ENVISAT Product Reader Python API — PyEPR 0.4 documentation

### Navigation

- index
- modules |
- next |
- PyEPR 0.4 documentation »

# ENVISAT Product Reader Python API

HomePage: | http://avalentino.github.com/pyepr
Author: | Antonio Valentino
Contact: | antonio.valentino@tiscali.it
Date: | 10/04/2011
Copyright: | 2011, Antonio Valentino <antonio.valentino@tiscali.it>
Version: | 0.4

## Overview

PyEPR provides Python bindings for the ENVISAT Product Reader C API (EPR API) for reading satellite data from ENVISAT ESA (European Space Agency) mission.

PyEPR, as well as the EPR API for C, supports ENVISAT MERIS, AATSR Level 1B and Level 2 and also ASAR data products. It provides access to the data either on a geophysical (decoded, ready-to-use pixel samples) or on a raw data layer. The raw data access makes it possible to read any data field contained in a product file.

## Documentation

- User Manual
  - Quick start
  - Requirements
  - Download
  - Installation
  - Testing
  - Python vs C API
  - Memory management
  - Arrays
  - Enumerators
  - Error handling and logging
  - Library initialization
  - High level API
  - Special methods
- Tutorial
  - Interactive use of PyEPR
- API Reference
  - Classes
  - Functions
  - Exceptions
  - Data
- Change history
  - PyEPR 0.4 10/04/2011
  - PyEPR 0.3 (01/04/2011)
  - PyEPR 0.2 (20/03/2011)
  - PyEPR 0.1 (09/03/2011)

## License

Copyright (C) 2011 Antonio Valentino <antonio.valentino@tiscali.it>

PyEPR is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

PyEPR is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details. You should have received a copy of the GNU General Public License along with PyEPR. If not, see <http://www.gnu.org/licenses/>.

### Navigation

- index
- modules |
- next |
- PyEPR 0.4 documentation »